from pathlib import Path, PosixPath
from typing import Union
import os
import sys

#Store attributes in a dicectory using a dict
class Node(object):
    __slots__ = ['_path_', '__dict__']

    def __init__(self, path: Union[str, Path, PosixPath]):
        self._path_ = path if isinstance(path, PosixPath) else Path(path).resolve()
        self.__dict__.update(dict.fromkeys([_ for _ in self._path_.iterdir()]))

    def __repr__(self):
        return '<sysfs.Node "%s">' % self._path_

    def __str__(self):
        return self._path_.name

    def __setattr__(self, name: str, val):
        if name.startswith('_'):
            return object.__setattr__(self, name, val)

        path = self._path_ / name
        if path.is_file():
            try:
                with path.open('w') as fp:
                    fp.write(val)
            except PermissionError:
                print("Please use root privileges!")
        else:
            print('Cannot write to non-files.', file=sys.stderr)

    def __getattribute__(self, name):
        if name.startswith('_'):
            return object.__getattribute__(self, name)

        path = self._path_ / name
        if path.is_file():
            try:
                with path.open('r') as fp:
                    return fp.read().strip()
            except PermissionError:
                print("Please use root privileges!")
        elif path.is_dir():
            return Node(path)

    def __setitem__(self, name, val):
        return setattr(self, name, val)

    def __getitem__(self, name):
        return getattr(self, name)

    def __iter__(self):
        return iter(getattr(self, str(name)) for name in self._path_.iterdir() if name.is_file())
