"""
usage:
   xdxsmi out [options]

options:
    -h, --help                    print this help message
"""

import os
from typing import Dict
from xdxsmi.api.third_party_docopt import docopt
# from xdxsmi.api.xdxgpu import XdxGpu
from xdxsmi.api.out_of_band_gpu_info import XdxGpuInfo
from xdxsmi.api.smi import XdxSmi
from get_set_attrs import setAttrs, getAttrs
from xdxsmi.api.pyxdxml import is_out_of_band

def printAttributes(gpu: XdxGpuInfo, args: Dict):
    processInfo = f"""\
        Process
                GUP ID              : {'N/A'}
                PID                 : {'N/A'}
                Process Name        : {'N/A'}
                Memory Usage        : {'N/A'}"""

    gpuAttrs = f"""\
    GPU {gpu.user_index}
        Product Name                : {gpu.name}
        Chip Model                  : {gpu.chip_model}
        Temprature                  : {gpu.temp}
        VBIOS Version               : {gpu.vbios}
        FW Version                  : {gpu.fm_ver}
        PCI
            Bus                     : {gpu.bus}
            Device                  : {gpu.dev}
            Domain                  : {gpu.domain}
            Device Id               : {gpu.device_id}
            Bus Id                  : {gpu.pci_bdf}
        FB Memory Usage(MiB)
            Total                   : {gpu.fb_total}
        Power
            Volt                    : {gpu.volt}
            Current                 : {gpu.current}
            Pwr                     : {gpu.pwr}
            Pwr Total               : {gpu.pwr_total}
        Fan Speed[RPM]              : {gpu.fan_spd}
        Clocks
            Graphics                : {gpu.gfx_clk}\n"""

    print(gpuAttrs)

def handle(xdx_smi: XdxSmi, args: Dict):
    header = f"""\
    Version                         : {xdx_smi.smi_ver}
==========================XDXSMI LOG==========================
    Timestamp                       : {xdx_smi.timestp}
    Attached GPUs                   : {xdx_smi.gpuNums}\n"""

    # if driver is loaded, out can get info without root authority
    # 'xdxsmi out' runs with root authority only if driver is not loaded.
    if(os.geteuid() != 0 and is_out_of_band() == 1):
        exit()

    print(header)

    for xdxgpu in xdx_smi.xdxgpus:
        printAttributes(xdxgpu, args)


if __name__ == "__main__":
    print(docopt(__doc__))