"""
usage:
   xdxsmi util [options] get [<ip>...]

options:
   -h, --help            print this help message
   -f, --filename=file   redirect query output to a specified file
   -l, --loop=sec        set look up interval, whose unit is second [default: -1]
   -i, --index=val   target gpu to read/write attributes, start from 0 [default: -1]
"""

from typing import Dict
from xdxsmi.api.third_party_docopt import docopt
from xdxsmi.api.smi import XdxSmi
from xdxsmi.api.pyxdxml import *
from xdxsmi.cli.render import Render
from xdxsmi.api.xdxgpu import XdxGpu
from get_set_attrs import setAttrs, getAttrs


def handle(xdx_smi: XdxSmi, args: Dict):
    #Collect target gpus
    #target_gpus = [xdx_smi.handle[0]]
    target_gpus = xdx_smi.handle
    if args["get"]:
        data = []
        i = 0
        header = ["INDEX", "GPU", "NAME", "GPU", "TDM", "GEOM", "3D", "CDM"]
        data.insert(0, header)

        for xdev in target_gpus:
            utilInfo = xdxml_device_get_util_info(xdev)
            row = [ str(i),
                    xdxml_device_get_pci_info(xdev).pci_dbdf.decode("utf8"),
                    xdxml_device_get_device_model(xdev).decode('utf-8'),
                    str(utilInfo.gpu)  + "%",
                    str(utilInfo.tdm)  + "%",
                    str(utilInfo.geom) + "%",
                    str(utilInfo.thrd) + "%",
                    str(utilInfo.cdm)  + "%"]
            data.append(row)
            i += 1
        Render.render_table(data, args)

    else:
        exit("%r is not a xdxsmi power command."\
             "See 'xdxsmi util --help'." % args['<command>'])

if __name__ == "__main__":
    print(docopt(__doc__))